##  Repository
The repository section within the metadata part of the manifest file provides details about the repository hosting the microservice.
Attribute | Required | Description
---|---|---
url | Yes | The URL of the repository hosting the microservice code.
status | No | The status of the repository, indicating whether it's ACTIVE or ARCHIVED.
visibility | No | The visibility of the repository, specifying whether it's INTERNAL, PRIVATE, or PUBLIC.


**Note**
Ensure that the tag groups, applications, and teams that you want to associate with your microservice exist in your SAP LeanIX workspace.
